@@ -11,7 +11,7 @@ function initialize!(integrator, cache::EulerConstantCache)
 end
 
 function perform_step!(integrator, cache::EulerConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, f, p = integrator
+    (; t, dt, uprev, f, p) = integrator
     @muladd u = @.. broadcast=false uprev+dt * integrator.fsalfirst
     k = f(u, p, t + dt) # For the interpolation, needs k at the updated point
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
@@ -24,7 +24,7 @@ end
 get_fsalfirstlast(cache::EulerCache, u) = (cache.fsalfirst, cache.k)
 function initialize!(integrator, cache::EulerCache)
     integrator.kshortsize = 2
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
     integrator.fsalfirst = fsalfirst
     integrator.fsallast = k
     resize!(integrator.k, integrator.kshortsize)
@@ -35,7 +35,7 @@ function initialize!(integrator, cache::EulerCache)
 end
 
 function perform_step!(integrator, cache::EulerCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     @muladd @.. broadcast=false u=uprev + dt * integrator.fsalfirst
     f(integrator.fsallast, u, p, t + dt) # For the interpolation, needs k at the updated point
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
@@ -56,7 +56,7 @@ end
 @muladd function perform_step!(integrator,
         cache::Union{HeunConstantCache, RalstonConstantCache},
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsalfirst = integrator
+    (; t, dt, uprev, u, f, p, fsalfirst) = integrator
 
     # precalculations
     if cache isa HeunConstantCache
@@ -100,7 +100,7 @@ end
 get_fsalfirstlast(cache::Union{HeunCache, RalstonCache}, u) = (cache.fsalfirst, cache.k)
 function initialize!(integrator, cache::Union{HeunCache, RalstonCache})
     integrator.kshortsize = 2
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
     integrator.fsalfirst = fsalfirst
     integrator.fsallast = k
     resize!(integrator.k, integrator.kshortsize)
@@ -112,8 +112,8 @@ end
 
 @muladd function perform_step!(integrator, cache::Union{HeunCache, RalstonCache},
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack fsalfirst, k, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; fsalfirst, k, tmp, atmp, stage_limiter!, step_limiter!, thread) = cache
 
     # precalculations
     if cache isa HeunCache
@@ -170,7 +170,7 @@ end
 
 @muladd function perform_step!(integrator, cache::MidpointConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     halfdt = dt / 2
     tmp = @.. broadcast=false uprev+halfdt * integrator.fsalfirst
     k = f(tmp, p, t + halfdt)
@@ -191,7 +191,7 @@ end
 
 get_fsalfirstlast(cache::MidpointCache, u) = (cache.fsalfirst, cache.k)
 function initialize!(integrator, cache::MidpointCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
     integrator.fsalfirst = fsalfirst
     integrator.fsallast = k
     integrator.kshortsize = 2
@@ -203,8 +203,8 @@ function initialize!(integrator, cache::MidpointCache)
 end
 
 @muladd function perform_step!(integrator, cache::MidpointCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tmp, k, fsalfirst, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tmp, k, fsalfirst, atmp, stage_limiter!, step_limiter!, thread) = cache
     halfdt = dt / 2
     @.. broadcast=false thread=thread tmp=uprev + halfdt * fsalfirst
     stage_limiter!(k, tmp, p, t + halfdt)
@@ -237,7 +237,7 @@ function initialize!(integrator, cache::RK4ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::RK4ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     halfdt = dt / 2
     k₁ = integrator.fsalfirst
     ttmp = t + halfdt
@@ -290,7 +290,7 @@ end
 
 get_fsalfirstlast(cache::RK4Cache, u) = (cache.fsalfirst, cache.k)
 function initialize!(integrator, cache::RK4Cache)
-    @unpack tmp, fsalfirst, k₂, k₃, k₄, k = cache
+    (; tmp, fsalfirst, k₂, k₃, k₄, k) = cache
     integrator.fsalfirst = fsalfirst
     integrator.fsallast = k
     integrator.kshortsize = 2
@@ -302,8 +302,8 @@ function initialize!(integrator, cache::RK4Cache)
 end
 
 @muladd function perform_step!(integrator, cache::RK4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tmp, fsalfirst, k₂, k₃, k₄, k, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tmp, fsalfirst, k₂, k₃, k₄, k, atmp, stage_limiter!, step_limiter!, thread) = cache
     k₁ = fsalfirst
     halfdt = dt / 2
     ttmp = t + halfdt
@@ -386,8 +386,8 @@ function initialize!(integrator, cache::Anas5ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::Anas5ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack a21, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, c2, c3, c4, c5, c6, b1, b3, b4, b5, b6 = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; a21, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, c2, c3, c4, c5, c6, b1, b3, b4, b5, b6) = cache
     ## Note that c1 and b2 were 0.
     alg = unwrap_alg(integrator, false)
     w = alg.w
@@ -438,10 +438,10 @@ function initialize!(integrator, cache::Anas5Cache)
 end
 
 @muladd function perform_step!(integrator, cache::Anas5Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     uidx = eachindex(integrator.uprev)
-    @unpack k1, k2, k3, k4, k5, k6, k7, utilde, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack a21, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, c2, c3, c4, c5, c6, b1, b3, b4, b5, b6 = cache.tab
+    (; k1, k2, k3, k4, k5, k6, k7, utilde, tmp, atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; a21, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, c2, c3, c4, c5, c6, b1, b3, b4, b5, b6) = cache.tab
     alg = unwrap_alg(integrator, false)
     w = alg.w
     v = w * dt
